package com.ynet.life.loaf.compare;

import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.DataMappingProvider;
import com.ynet.life.loaf.LOAFHelper;
import com.ynet.life.loaf.LoafTools;
import com.ynet.life.loaf.TableConfig;
import com.ynet.life.loaf.jdbc.LoafPreparedQuery;
import com.ynet.life.loaf.jdbc.LoafQueryCondition;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/* loaded from: com_ynet_life_loaf_compare.jar:com/ynet/life/loaf/compare/CompareGenerator.class */
public class CompareGenerator {
    public static Map generate(Map context, String businessCode) throws TranFailException, SQLException {
        TableConfig tableConfig = DataMappingProvider.getTableConfig(businessCode);
        Map changeMap = new HashMap();
        HashMap hashMap = new HashMap();
        getChangeValue(context, tableConfig, changeMap);
        changeMap.put("originalData", hashMap);
        compare(LifeDBAccess.getConnection(), context, tableConfig, hashMap);
        return changeMap;
    }

    private static void getChangeValue(Map context, TableConfig tableConfig, Map changeMap) throws TranFailException {
        String iCollName = LOAFHelper.getICollName(tableConfig);
        if (iCollName != null && iCollName.length() > 0) {
            changeMap.put(iCollName, context.get(iCollName));
            LoafTools.addContextFieldToIColl(context, tableConfig, changeMap);
        } else {
            for (String fieldName : tableConfig.getDataToTableFieldHashMap().keySet()) {
                changeMap.put(fieldName, context.get(fieldName));
            }
        }
        List<String> subBusinessList = tableConfig.getSubBusinessList();
        if (subBusinessList != null && subBusinessList.size() > 0) {
            for (String subBusinessCode : subBusinessList) {
                getChangeValue(context, DataMappingProvider.getTableConfig(subBusinessCode), changeMap);
            }
        }
    }

    private static void compare(Connection connection, Map context, TableConfig tableConfig, Map originalMap) throws TranFailException, SQLException {
        String parentOpTypeStr = (String) context.get("opType");
        String iCollName = LOAFHelper.getICollName(tableConfig);
        if (iCollName != null && iCollName.length() > 0) {
            IndexedCollection icoll = (IndexedCollection) context.get(iCollName);
            for (int i = 0; i < icoll.size(); i++) {
                KeyedCollection kcoll = icoll.getElementAt(i);
                String str = (String) kcoll.get("opType");
                String opTypeStr = str;
                if (str == null || opTypeStr.length() == 0) {
                    opTypeStr = parentOpTypeStr;
                    kcoll.put("opType", parentOpTypeStr);
                }
                int opType = Integer.parseInt(opTypeStr);
                if (2 == opType) {
                    Map resultMap = getOriginalValue(connection, kcoll, tableConfig);
                    kcoll.putAll(resultMap);
                } else if (3 == opType || 4 == opType) {
                    Map resultMap2 = getOriginalValue(connection, kcoll, tableConfig);
                    IndexedCollection indexedCollection = (IndexedCollection) originalMap.get(iCollName);
                    IndexedCollection originalIColl = indexedCollection;
                    if (indexedCollection == null) {
                        originalIColl = new IndexedCollection();
                        originalMap.put(iCollName, originalIColl);
                    }
                    KeyedCollection originalKColl = new KeyedCollection();
                    originalKColl.putAll(resultMap2);
                    originalIColl.add(originalKColl);
                }
            }
        } else {
            int parentOpType = Integer.parseInt(parentOpTypeStr);
            if (1 != parentOpType) {
                originalMap.putAll(getOriginalValue(connection, context, tableConfig));
            }
        }
        List<String> subBusinessList = tableConfig.getSubBusinessList();
        if (subBusinessList != null && subBusinessList.size() > 0) {
            for (String subBusinessCode : subBusinessList) {
                compare(connection, context, DataMappingProvider.getTableConfig(subBusinessCode), originalMap);
            }
        }
    }

    private static Map getOriginalValue(Connection connection, Map context, TableConfig tableConfig) throws SQLException {
        Map originalMap = new HashMap();
        LoafTools.addICollField(context, tableConfig);
        LoafQueryCondition queryCondition = new LoafQueryCondition(tableConfig, context);
        ResultSet resultSet = new LoafPreparedQuery(tableConfig, queryCondition, (String) null).getPreparedStatement(connection).executeQuery();
        if (resultSet.next()) {
            Map tableFieldMap = tableConfig.getTableFieldToDataHashMap();
            for (String tableField : tableFieldMap.keySet()) {
                String dataField = (String) tableFieldMap.get(tableField);
                String originalValue = resultSet.getString(tableField);
                originalMap.put(getFieldNameWithoutICollName(dataField), originalValue);
            }
        }
        return originalMap;
    }

    private static String getFieldNameWithoutICollName(String fieldName) {
        String name = fieldName;
        if (fieldName != null && fieldName.indexOf("@") > 0) {
            name = fieldName.substring(fieldName.indexOf("@") + 1);
        }
        return name;
    }
}
